pub struct BorromeanRange {
pub(crate) sigs: BorromeanSignatures,
pub(crate) bit_commitments: [CompressedPoint; 64],
}Expand description
A range proof premised on Borromean ring signatures.
Fields
sigs: BorromeanSignaturesbit_commitments: [CompressedPoint; 64]Implementations
Sourceimpl BorromeanRange
impl BorromeanRange
Sourcepub fn read<R>(r: &mut R) -> Result<BorromeanRange, Error>where
R: Read,
pub fn read<R>(r: &mut R) -> Result<BorromeanRange, Error>where
R: Read,
Read a BorromeanRange proof.
Sourcepub fn write<W>(&self, w: &mut W) -> Result<(), Error>where
W: Write,
pub fn write<W>(&self, w: &mut W) -> Result<(), Error>where
W: Write,
Write the BorromeanRange proof.
Sourcepub fn verify(&self, commitment: &CompressedPoint) -> bool
pub fn verify(&self, commitment: &CompressedPoint) -> bool
Verify the commitment contains a 64-bit coefficient for the H generator.
This DOES NOT confirm that the result is a Pedersen commitment in the prime-order subgroup, as the Monero protocol does not have such a bound. This MUST only be used as expected by the Monero protocol, with all associated expectations.